==> open_watcom_1.6.0-src.zip: bld/wpi/c/wpi_dbcs.c <==
/****************************************************************************
*
*                            Open Watcom Project
*
*    Portions Copyright (c) 1983-2002 Sybase, Inc. All Rights Reserved.
*
*  ========================================================================
*
*    This file contains Original Code and/or Modifications of Original
*    Code as defined in and that are subject to the Sybase Open Watcom
*    Public License version 1.0 (the 'License'). You may not use this file
*    except in compliance with the License. BY USING THIS FILE YOU AGREE TO
*    ALL TERMS AND CONDITIONS OF THE LICENSE. A copy of the License is
*    provided with the Original Code and Modifications, and is also
*    available at www.sybase.com/developer/opensource.
*
*    The Original Code and all software distributed under the License are
*    distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
*    EXPRESS OR IMPLIED, AND SYBASE AND ALL CONTRIBUTORS HEREBY DISCLAIM
*    ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR
*    NON-INFRINGEMENT. Please see the License for the specific language
*    governing rights and limitations under the License.
*
*  ========================================================================
*
* Description:  WPI OS/2 DBCS routines.
*
****************************************************************************/


#define INCL_PM
#define INCL_DOSNLS
#include <os2.h>
#include "wpi.h"


BOOL _wpi_is_dbcs( void )
/***********************/

{
    COUNTRYCODE                 code;
    UCHAR                       dbcs_env[12];

    code.country = 0;
    code.codepage = 0;
#ifdef __386__
    DosQueryDBCSEnv( 12, &code, dbcs_env );
#else
    DosGetDBCSEv( 12, &code, dbcs_env );
#endif

    return( dbcs_env[0] | dbcs_env[1] );
}

void _wpi_fix_dbcs( HWND dlg )
/****************************/

{
    /* stolen from David Brandow's code in VX-REXX. */
    #define DBCS_FONT   "10.Mincho"

    WinRemovePresParam( dlg, PP_FONTNAMESIZE );
    WinSetPresParam( dlg, PP_FONTNAMESIZE, sizeof(DBCS_FONT), DBCS_FONT );
}

==> open_watcom_1.7.0-src.zip: bld/wpi/c/wpi_dbcs.c <==
/****************************************************************************
*
*                            Open Watcom Project
*
*    Portions Copyright (c) 1983-2002 Sybase, Inc. All Rights Reserved.
*
*  ========================================================================
*
*    This file contains Original Code and/or Modifications of Original
*    Code as defined in and that are subject to the Sybase Open Watcom
*    Public License version 1.0 (the 'License'). You may not use this file
*    except in compliance with the License. BY USING THIS FILE YOU AGREE TO
*    ALL TERMS AND CONDITIONS OF THE LICENSE. A copy of the License is
*    provided with the Original Code and Modifications, and is also
*    available at www.sybase.com/developer/opensource.
*
*    The Original Code and all software distributed under the License are
*    distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
*    EXPRESS OR IMPLIED, AND SYBASE AND ALL CONTRIBUTORS HEREBY DISCLAIM
*    ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR
*    NON-INFRINGEMENT. Please see the License for the specific language
*    governing rights and limitations under the License.
*
*  ========================================================================
*
* Description:  WPI OS/2 DBCS routines.
*
****************************************************************************/


#define INCL_PM
#define INCL_DOSNLS
#include <os2.h>
#include "wpi.h"


BOOL _wpi_is_dbcs( void )
/***********************/

{
    COUNTRYCODE                 code;
    CHAR                        dbcs_env[12];

    code.country = 0;
    code.codepage = 0;
#ifdef __386__
    DosQueryDBCSEnv( 12, &code, dbcs_env );
#else
    DosGetDBCSEv( 12, &code, dbcs_env );
#endif

    return( dbcs_env[0] | dbcs_env[1] );
}

void _wpi_fix_dbcs( HWND dlg )
/****************************/

{
    /* stolen from David Brandow's code in VX-REXX. */
    #define DBCS_FONT   "10.Mincho"

    WinRemovePresParam( dlg, PP_FONTNAMESIZE );
    WinSetPresParam( dlg, PP_FONTNAMESIZE, sizeof(DBCS_FONT), DBCS_FONT );
}
